==> postLdapAdmin-1.0.tar.gz: postLdapAdmin/htdocs/admin/admin_user_menu.php <==
<?php

/*
 * postLdapAdmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * ѥ桼˥
 *
 * $RCSfile: admin_user_menu.php,v $
 * $Revision: 1.11 $
 * $Date: 2007/08/16 02:11:44 $
 **********************************************************/

include_once("../../lib/libcommon");
include_once("../../lib/libpage");
include_once("../../lib/libsess");
include_once("../../lib/libldap");

/********************************************************
ƥڡ
*********************************************************/

/* ֤μ */
define("MY_TAB", TAB_USER);

/* ѥ󤯤ꥹ */
$topic[0]["name"] = TOPIC_USER_CONTROL;
$topic[0]["url"] = "";

/* ƹԤκ˥塼ܥ */
define("MPL", 4);

/* ˥塼ܥꥹ */
$menu[0]["name"] = "桼ɽ";
$menu[0]["img"] = "images/icon_image2.gif";
$menu[0]["url"] = "admin_user_search.php";
$menu[1]["name"] = "桼Ͽ";
$menu[1]["img"] = "images/icon_image1.gif";
$menu[1]["url"] = "admin_user_add.php";

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {

        global $menu;

        print "\n<table class=\"body\">\n";

        $mcount = count($menu);

        for ($i = 0; $i < $mcount; $i++) {

            $odd = ($i + 1) % MPL;
            /* ƬΥ˥塼ˤ<tr>֤ */
            if ($i == 0 || ($i != 1 && $odd == 1)) {
                print "    <tr>\n";
            }
print <<<EOD
        <td class="menu">
            <a href="#" onClick="dgpSubmit('{$menu[$i]["url"]}')"><img class="menu" src="{$menu[$i]["img"]}"><br>{$menu[$i]["name"]}</a>
        </td>

EOD;

            /* ǸǤˤ</tr>֤ */
            if (($i + 1) == $mcount) {
                /* ˥塼ԤΥ˥塼ɽʤ硢
                   ˥塼ǤԤɽǳڤ</tr>֤ */
                if ($mcount < MPL || $odd == 0) {
                    print "    </tr>\n";
                } else {

                    /* Ĥäơ֥Υˤ϶֤Ǹ</tr> */
                    for ($n = 0; $n < (MPL - $odd); $n++) {
                        print "        <td><img src=\"images/spacer.gif\"></td>\n";
                    }
                    print "    </tr>\n";
                }
            /* ƹԤνˤ</tr>֤ */
            } elseif ($i != 0 && $odd == 0) {
                print "    </tr>\n";
            } 
        }

        print "</table>\n";

    }

};

/***********************************************************
 * 
 **********************************************************/
/* 󥹥󥹺 */
$pg  = new my_page();
if (isset($_POST["sk"])) {
    $sesskey = $_POST["sk"];
}

/* ɥᥤ */
$domain = $_SERVER['DOMAIN'];

/* եɹ */
$ret = read_web_conf();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(null, null);
    exit (1);
}

/* Ź沽Υѥ򥻥å */
$admkey_file = BASEDIR . ETCDIR . $domain . "/" . ADMKEY;

/* å */
if (isset($sesskey) === FALSE) {
    header("Location: index.php?e=2");
    exit (1);
}

/* åå */
if (is_sysadm($sesskey) !== TRUE) {
    header("Location: index.php?e=1");
    exit (1);
}

/* 顼å */
if (isset($_POST["msg"])) {
    $err_msg = $_POST["msg"];
} else {
    $err_msg = "";
}

/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display($topic, MY_TAB);

?>

==> postLdapAdmin-1.2.tar.gz: postLdapAdmin/htdocs/admin/admin_user_menu.php <==
<?php

/*
 * postLdapAdmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * ѥ桼˥
 *
 * $RCSfile: admin_user_menu.php,v $
 * $Revision: 1.13 $
 * $Date: 2008/11/20 00:02:05 $
 **********************************************************/

include_once("../../lib/libcommon");
include_once("../../lib/libpage");
include_once("../../lib/libsess");
include_once("../../lib/libldap");

/********************************************************
ƥڡ
*********************************************************/

/* ֤μ */
define("MY_TAB", TAB_USER);

/* ѥ󤯤ꥹ */
$topic[0]["name"] = TOPIC_USER_CONTROL;
$topic[0]["url"] = "";

/* ƹԤκ˥塼ܥ */
define("MPL", 4);

/* ˥塼ܥꥹ */
$menu[0]["name"] = "桼ɽ";
$menu[0]["img"] = "images/icon_image2.gif";
$menu[0]["url"] = "admin_user_search.php";
$menu[1]["name"] = "桼Ͽ";
$menu[1]["img"] = "images/icon_image1.gif";
$menu[1]["url"] = "admin_user_add.php";
$menu[2]["name"] = "CSV";
$menu[2]["img"] = "images/icon_image3.gif";
$menu[2]["url"] = "admin_user_csv_batch.php";

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {

        global $menu;

        print "\n<table class=\"body\">\n";

        $mcount = count($menu);

        for ($i = 0; $i < $mcount; $i++) {

            $odd = ($i + 1) % MPL;
            /* ƬΥ˥塼ˤ<tr>֤ */
            if ($i == 0 || ($i != 1 && $odd == 1)) {
                print "    <tr>\n";
            }
print <<<EOD
        <td class="menu">
            <a href="#" onClick="dgpSubmit('{$menu[$i]["url"]}')"><img class="menu" src="{$menu[$i]["img"]}"><br>{$menu[$i]["name"]}</a>
        </td>

EOD;

            /* ǸǤˤ</tr>֤ */
            if (($i + 1) == $mcount) {
                /* ˥塼ԤΥ˥塼ɽʤ硢
                   ˥塼ǤԤɽǳڤ</tr>֤ */
                if ($mcount < MPL || $odd == 0) {
                    print "    </tr>\n";
                } else {

                    /* Ĥäơ֥Υˤ϶֤Ǹ</tr> */
                    for ($n = 0; $n < (MPL - $odd); $n++) {
                        print "        <td><img src=\"images/spacer.gif\"></td>\n";
                    }
                    print "    </tr>\n";
                }
            /* ƹԤνˤ</tr>֤ */
            } elseif ($i != 0 && $odd == 0) {
                print "    </tr>\n";
            } 
        }

        print "</table>\n";

    }

};

/***********************************************************
 * 
 **********************************************************/
/* 󥹥󥹺 */
$pg  = new my_page();
if (isset($_POST["sk"])) {
    $sesskey = $_POST["sk"];
}

/* ɥᥤ */
$domain = $_SERVER['DOMAIN'];

/* եɹ */
$ret = read_web_conf();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(null, null);
    exit (1);
}

/* Ź沽Υѥ򥻥å */
$admkey_file = BASEDIR . ETCDIR . $domain . "/" . ADMKEY;

/* å */
if (isset($sesskey) === FALSE) {
    header("Location: index.php?e=2");
    exit (1);
}

/* åå */
if (is_sysadm($sesskey) !== TRUE) {
    header("Location: index.php?e=1");
    exit (1);
}

/* 顼å */
if (isset($_POST["msg"])) {
    $err_msg = $_POST["msg"];
} else {
    $err_msg = "";
}

/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display($topic, MY_TAB);

?>
